=========
Changelog
=========


Version 0.1.2
-------------
- Refactor of axis functionality into separate module, with lots of bug fixes
  and proper testing
- Added ``barh`` plotting function
- Automatic build and deploy in travis ci


Version 0.1.1
-------------
- Added basic docs
- Added color support in ``plot`` function, with legend
- Minor refactoring and bug fixing in axis and drawing


Version 0.1
-----------

- Basic functionality of shellplot released.
- Includes ``plot`` and ``hist`` functions which print to the command line.
- Includes pandas backend api for the above
